Learn R Programming

rusda (version 1.0.8)

literature: Downloads literature from SMML Literature DB

Description

Searches and downloads literature entries from the SMML Literature database

Usage

literature(x, spec_type = c("plant", "fungus"), process = TRUE)

Arguments

x
a vector of class character containing fungal or plant species names
spec_type
a character string specifying the type of spec. Can be either "plant" or "fungus"
process
logical, if TRUE downloading and extraction process is displayed

an object of class list

Value

a vector of mode list with literature entries for x

Examples

Run this code
## Not run: 
# x <- "Polyporus badius"
# lit <- literature(x, process = TRUE, spec_type = "fungus")
# lit
# ## End(Not run)

Run the code above in your browser using DataLab