Learn R Programming

rusda (version 1.0.8)

meta_smml: Downloads and evaluate species presence in SMML DBs

Description

Searches, downloads and evaluates presence/absence of data in the SMML databases

Usage

meta_smml(x, spec_type = c("plant", "fungus"), process = TRUE)

Arguments

x
a vector of class character containing fungal or plant species or genus names
spec_type
a character string specifying the type of x. Can be either "plant" or "fungus"
process
logical, if TRUE downloading and extraction process is displayed

Value

an object of class data.frame: presence/absence

Details

Use this function before deriving data from one of the databases in order to prune your input species vector. With pruned species vectors the functions will run faster. This is important if x is some hundred species long.

Examples

Run this code
## Not run: 
# fungus.meta <- meta_smml(x = "Picea abies", process = TRUE, spec_type = "plant")
# fungus.meta
# hosts.meta <- meta_smml(x = "Antrodiella citrinella", process = TRUE, spec_type = "fungus")
# hosts.meta
# ## End(Not run)

Run the code above in your browser using DataLab