Learn R Programming

rusda (version 1.0.8)

synonyms_smml: Downloads synonym data from SMML Nomenclature DB

Description

Searches and downloads synonym data from SMML Nomenclature database

Usage

synonyms_smml(x, spec_type = c("plant", "fungus"), clean = TRUE, process = TRUE)

Arguments

x
a vector of class character containing fungal or plant species or genus names
spec_type
a character string specifying the type of x. Can be either "plant" or "fungus"
clean
logical, if TRUE a cleaning step is run of the resulting associations list
process
logical, if TRUE downloading and extraction process is displayed

Value

an object of class list containing synonyms for x

Examples

Run this code
## Not run: 
# x <- "Solanum tuberosum"
# synonyms_usda(x, spec_type = "plant", process = TRUE, clean = TRUE)
# x <- c("Phytophthora infestans", "Polyporus badius")
# synonyms_usda(x, spec_type = "fungus", process = TRUE, clean = TRUE)
# ## End(Not run)

Run the code above in your browser using DataLab